#Duphunter

Duphunter is an application that finds and lets you delete duplicate files interactively, using a very efficient list interface where you can mark files for preservation or deletion, and later commit your changes.

The repository, bug tracker and Web site for this tool is at [http://github.com/Rudd-O/zfs-tools](http://github.com/Rudd-O/duphunter).  Comments to me through rudd-o@rudd-o.com.
